@@ -15,17 +15,17 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import inspect
 import sys
-if not hasattr(sys, "version_info") or sys.version_info < (3, 9, 0, "final", 0):
-    raise SystemExit("This program requires Python 3.9 or later.")
+if not hasattr(sys, "version_info") or sys.version_info < (3, 10, 0, "final", 0):
+    raise SystemExit("This program requires Python 3.10 or later.")
 import os
 import shutil
-import stat
 import importlib
 # PEP 396
 from .configuration import App, Version as __version__ # noqa: F401
+from . import fileutil, log, util
 __all__ = ['list_formats', 'list_archive', 'extract_archive', 'test_archive',
     'create_archive', 'diff_archives', 'search_archive', 'repack_archive',
-    'is_archive', 'recompress_archive', 'program_supports_compression']
+    'is_archive', 'program_supports_compression']
 
 
 # Supported archive commands
@@ -271,8 +271,8 @@ ArchivePrograms = {
     },
     'zip': {
         None: ('7z', '7za', 'py_zipfile'),
-        'extract': ('unzip', 'unar'),
-        'list': ('unzip',),
+        'extract': ('unzip', 'unar', 'jar'),
+        'list': ('unzip', 'jar'),
         'test': ('zip', 'unzip',),
         'create': ('zip',),
     },
@@ -296,9 +296,6 @@ NoPasswordSupportArchivePrograms = {
     'cab': {
         None: ('7z', )
     },
-    'zip': {
-        'create': ('py_zipfile', ),
-    },
     'arj': {
         None: ('7z',)
         },
@@ -326,6 +323,11 @@ NoPasswordSupportArchivePrograms = {
     'xz': {
         None: ('7z',)
     },
+    'zip': {
+        'create': ('py_zipfile',),
+        'extract': ('jar',),
+        'list': ('jar',),
+    },
 }
 
 # List those programs that have different python module names because of
@@ -340,50 +342,51 @@ ProgramModules = {
 }
 
 
-def program_supports_compression (program, compression):
+def program_supports_compression(program, compression):
     """Decide if the given program supports the compression natively.
     @return: True iff the program supports the given compression format
       natively, else False.
     """
     if program in ('tar', ):
+        if os.name == 'nt':
+            return compression in ('gzip', 'bzip2')
         return compression in (
-            'gzip', 'bzip2', 'xz', 'lzip',
-            'compress', 'lzma', 'py_lzma', 'zstd',
+            'bzip2', 'compress', 'gzip', 'lzip', 'lzma', 'xz', 'zstd',
         )
     elif program in ('star', 'bsdtar', 'py_tarfile'):
-        return compression in ('gzip', 'bzip2', 'py_lzma')
+        return compression in ('gzip', 'bzip2', 'lzma')
     return False
 
 
-from . import util # noqa: E402
+from .mime import guess_mime # noqa: E402
 
 def is_archive(filename):
     """Detect if the file is a known archive."""
-    mime, compression = util.guess_mime(filename)
+    mime, compression = guess_mime(filename)
     return mime in ArchiveMimetypes
 
 
-def get_archive_format (filename):
+def get_archive_format(filename):
     """Detect filename archive format and optional compression."""
-    mime, compression = util.guess_mime(filename)
+    mime, compression = guess_mime(filename)
     if not (mime or compression):
-        raise util.PatoolError("unknown archive format for file `%s'" % filename)
+        raise util.PatoolError(f"unknown archive format for file `{filename}'")
     if mime in ArchiveMimetypes:
         format = ArchiveMimetypes[mime]
     else:
-        raise util.PatoolError("unknown archive format for file `%s' (mime-type is `%s')" % (filename, mime))
+        raise util.PatoolError(f"unknown archive mime format {mime} for file `%s' (mime-type is `{filename}')")
     if format == compression:
         # file cannot be in same format compressed
         compression = None
     return format, compression
 
 
-def check_archive_format (format, compression):
+def check_archive_format(format, compression):
     """Make sure format and compression is known."""
     if format not in ArchiveFormats:
-        raise util.PatoolError("unknown archive format `%s'" % format)
+        raise util.PatoolError(f"unknown archive format `{format}'")
     if compression is not None and compression not in ArchiveCompressions:
-        raise util.PatoolError("unknown archive compression `%s'" % compression)
+        raise util.PatoolError(f"unknown archive compression `{compression}'")
 
 
 def find_archive_program (format, command, program=None, password=None):
@@ -400,7 +403,7 @@ def find_archive_program (format, command, program=None, password=None):
     if password is not None:
         programs = _remove_command_without_password_support(programs, format, command)
     if not programs:
-        raise util.PatoolError("%s archive format `%s' is not supported" % (command, format))
+        raise util.PatoolError(f"{command} archive format `{format}' is not supported")
     # return the first existing program
     for program in programs:
         if program.startswith('py_'):
@@ -431,7 +434,7 @@ def _remove_command_without_password_support(programs, format, command):
         if program not in no_password_support_programs:
             programs_with_support.append(program)
     if not programs_with_support and programs:
-        raise util.PatoolError("%s archive format `%s' with password is not supported" % (command, format))
+        raise util.PatoolError(f"{command} archive format `{format}' with password is not supported")
     return programs_with_support
 
 
@@ -480,8 +483,8 @@ def check_program_compression(archive, command, program, compression):
                 comp_command = 'extract'
             comp_prog = find_archive_program(compression, comp_command)
             if not comp_prog:
-                msg = "cannot %s archive `%s': compression `%s' not supported"
-                raise util.PatoolError(msg % (command, archive, compression))
+                msg = f"cannot {command} archive `{archive}': compression `{compression}' not supported"
+                raise util.PatoolError(msg)
 
 
 def move_outdir_orphan (outdir):
@@ -510,42 +513,21 @@ def run_archive_cmdlist (archive_cmdlist, verbosity=0):
     return util.run_checked(cmdlist, verbosity=verbosity, **runkwargs)
 
 
-def make_file_readable (filename):
-    """Make file user readable if it is not a link."""
-    if not os.path.islink(filename):
-        util.set_mode(filename, stat.S_IRUSR)
-
-
-def make_dir_readable (filename):
-    """Make directory user readable and executable."""
-    util.set_mode(filename, stat.S_IRUSR|stat.S_IXUSR)
-
-
-def make_user_readable (directory):
-    """Make all files in given directory user readable. Also recurse into
-    subdirectories."""
-    for root, dirs, files in os.walk(directory, onerror=util.log_error):
-        for filename in files:
-            make_file_readable(os.path.join(root, filename))
-        for dirname in dirs:
-            make_dir_readable(os.path.join(root, dirname))
-
-
-def cleanup_outdir (outdir, archive):
+def cleanup_outdir(outdir, archive):
     """Cleanup outdir after extraction and return target file name and
     result string."""
-    make_user_readable(outdir)
+    fileutil.make_user_readable(outdir)
     # move single directory or file in outdir
     (success, msg) = move_outdir_orphan(outdir)
     if success:
         # msg is a single directory or filename
-        return msg, "`%s'" % msg
+        return msg, f"`{msg}'"
     # outdir remains unchanged
     # rename it to something more user-friendly (basically the archive
     # name without extension)
-    outdir2 = util.get_single_outfile("", archive)
+    outdir2 = fileutil.get_single_outfile("", archive)
     os.rename(outdir, outdir2)
-    return outdir2, "`%s' (%s)" % (outdir2, msg)
+    return outdir2, f"`{outdir2}' ({msg})"
 
 
 def _extract_archive(archive, verbosity=0, interactive=True, outdir=None,
@@ -560,16 +542,16 @@ def _extract_archive(archive, verbosity=0, interactive=True, outdir=None,
     check_program_compression(archive, 'extract', program, compression)
     get_archive_cmdlist = get_archive_cmdlist_func(program, 'extract', format)
     if outdir is None:
-        outdir = util.tmpdir(dir=".")
+        outdir = fileutil.tmpdir(dir=".")
         do_cleanup_outdir = True
     else:
         do_cleanup_outdir = False
         if os.path.exists(outdir):
             if not os.path.isdir(outdir):
-                msg = "output path `%s' exists and is not a directory" % outdir
+                msg = f"output path `{outdir}' exists and is not a directory"
                 raise util.PatoolError(msg)
         else:
-            util.log_info("... creating output directory `%s'." % outdir)
+            log.log_info(f"... creating output directory `{outdir}'.")
             os.makedirs(outdir)
     try:
         cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, interactive, outdir, password=password)
@@ -581,17 +563,20 @@ def _extract_archive(archive, verbosity=0, interactive=True, outdir=None,
         if do_cleanup_outdir:
             target, msg = cleanup_outdir(outdir, archive)
         else:
-            target, msg = outdir, "`%s'" % outdir
+            target, msg = outdir, f"`{outdir}'"
         if verbosity >= 0:
-            util.log_info("... %s extracted to %s." % (archive, msg))
+            log.log_info(f"... {archive} extracted to {msg}.")
         return target
     finally:
         # try to remove an empty temporary output directory
-        if do_cleanup_outdir:
+        if do_cleanup_outdir and os.path.isdir(outdir):
             try:
                 os.rmdir(outdir)
-            except OSError:
-                pass
+            except OSError as err:
+                if sys.exc_info()[0] is not None:
+                    msg = "extraction error, could not remove temporary " \
+                          f"extraction directory {outdir}: {err}"
+                    log.log_error(msg)
 
 
 def _create_archive(archive, filenames, verbosity=0, interactive=True,
@@ -603,20 +588,12 @@ def _create_archive(archive, filenames, verbosity=0, interactive=True,
     program = find_archive_program(format, 'create', program=program, password=password)
     check_program_compression(archive, 'create', program, compression)
     get_archive_cmdlist = get_archive_cmdlist_func(program, 'create', format)
-    origarchive = None
-    if os.path.basename(program) == 'arc' and \
-       ".arc" in archive and not archive.endswith(".arc"):
-        # the arc program mangles the archive name if it contains ".arc"
-        origarchive = archive
-        archive = util.tmpfile(dir=os.path.dirname(archive), suffix=".arc")
     cmdlist = get_archive_cmdlist(archive, compression, program, verbosity, interactive, filenames, password=password)
     if cmdlist:
         # an empty command list means the get_archive_cmdlist() function
         # already handled the command (e.g. when it's a builtin Python
         # function)
         run_archive_cmdlist(cmdlist, verbosity=verbosity)
-    if origarchive:
-        shutil.move(archive, origarchive)
 
 
 def _handle_archive(archive, command, verbosity=0, interactive=True,
@@ -626,7 +603,7 @@ def _handle_archive(archive, command, verbosity=0, interactive=True,
         format, compression = get_archive_format(archive)
     check_archive_format(format, compression)
     if command not in ('list', 'test'):
-        raise util.PatoolError("invalid archive command `%s'" % command)
+        raise util.PatoolError(f"invalid archive command `{command}'")
     program = find_archive_program(format, command, program=program, password=password)
     check_program_compression(archive, command, program, compression)
     get_archive_cmdlist = get_archive_cmdlist_func(program, command, format)
@@ -639,22 +616,22 @@ def _handle_archive(archive, command, verbosity=0, interactive=True,
         run_archive_cmdlist(cmdlist, verbosity=verbosity)
 
 
-def get_archive_cmdlist_func (program, command, format):
+def get_archive_cmdlist_func(program, command, format):
     """Get the Python function that executes the given program."""
     # get python module for given archive program
-    key = util.stripext(os.path.basename(program).lower())
+    key = fileutil.stripext(os.path.basename(program).lower())
     modulename = ".programs." + ProgramModules.get(key, key)
     # import the module
     try:
         module = importlib.import_module(modulename, __name__)
     except ImportError as err:
-        msg = "cannot import module %s in %s" % (modulename, __name__)
+        msg = f"cannot import module {modulename} in {__name__}"
         raise util.PatoolError(msg) from err
     # get archive handler function (e.g. patoolib.programs.star.extract_tar)
     try:
-        archive_cmdlist_func = getattr(module, '%s_%s' % (command, format))
+        archive_cmdlist_func = getattr(module, f'{command}_{format}')
     except AttributeError as err:
-        msg = "could not find %s_%s in %s" % (command, format, module)
+        msg = f"could not find {command}_{format} in {module}"
         raise util.PatoolError(msg) from err
     def check_for_password_before_cmdlist_func_call(*args, **kwargs):
         """ If password is None, or not set, run command as usual.
@@ -668,32 +645,27 @@ def get_archive_cmdlist_func (program, command, format):
         else:
             if 'password' in inspect.signature(archive_cmdlist_func).parameters:
                 return archive_cmdlist_func(*args, **kwargs)
-            raise util.PatoolError('There is no support for password in %s' % program)
+            msg = f'There is no support for password in {program}'
+            raise util.PatoolError(msg)
     return check_for_password_before_cmdlist_func_call
 
 
-def rmtree_log_error (func, path, exc):
-    """Error function for shutil.rmtree(). Raises a PatoolError."""
-    msg = "Error in %s(%s): %s" % (func.__name__, path, str(exc[1]))
-    util.log_error(msg)
-
-
-def _diff_archives (archive1, archive2, verbosity=0, interactive=True):
+def _diff_archives(archive1, archive2, verbosity=0, interactive=True):
     """Show differences between two archives.
     @return 0 if archives are the same, else 1
     @raises: PatoolError on errors
     """
-    if util.is_same_file(archive1, archive2):
+    if fileutil.is_same_file(archive1, archive2):
         return 0
     diff = util.find_program("diff")
     if not diff:
         msg = "The diff(1) program is required for showing archive differences, please install it."
         raise util.PatoolError(msg)
-    tmpdir1 = util.tmpdir()
+    tmpdir1 = fileutil.tmpdir()
     try:
         path1 = _extract_archive(archive1, outdir=tmpdir1, verbosity=-1)
         entries1 = os.listdir(tmpdir1)
-        tmpdir2 = util.tmpdir()
+        tmpdir2 = fileutil.tmpdir()
         try:
             path2 = _extract_archive(archive2, outdir=tmpdir2, verbosity=-1)
             entries2 = os.listdir(tmpdir2)
@@ -706,11 +678,9 @@ def _diff_archives (archive1, archive2, verbosity=0, interactive=True):
                 diffpath2 = path2
             return util.run_checked([diff, "-urN", diffpath1, diffpath2], verbosity=1, ret_ok=(0, 1))
         finally:
-            make_user_readable(tmpdir2)
-            shutil.rmtree(tmpdir2, onerror=rmtree_log_error)
+            fileutil.rmtree(tmpdir2)
     finally:
-        make_user_readable(tmpdir1)
-        shutil.rmtree(tmpdir1, onerror=rmtree_log_error)
+        fileutil.rmtree(tmpdir1)
 
 
 def _search_archive(pattern, archive, verbosity=0, interactive=True, password=None):
@@ -719,23 +689,23 @@ def _search_archive(pattern, archive, verbosity=0, interactive=True, password=No
     if not grep:
         msg = "The grep(1) program is required for searching archive contents, please install it."
         raise util.PatoolError(msg)
-    tmpdir = util.tmpdir()
+    tmpdir = fileutil.tmpdir()
     try:
         path = _extract_archive(archive, outdir=tmpdir, verbosity=-1, password=password)
         return util.run_checked([grep, "-r", "-e", pattern, "."], ret_ok=(0, 1), verbosity=1, cwd=path)
     finally:
-        shutil.rmtree(tmpdir, onerror=rmtree_log_error)
+        fileutil.rmtree(tmpdir)
 
 
-def _repack_archive (archive1, archive2, verbosity=0, interactive=True, password=None):
+def _repack_archive(archive1, archive2, verbosity=0, interactive=True, password=None):
     """Repackage an archive to a different format."""
     format1, compression1 = get_archive_format(archive1)
     format2, compression2 = get_archive_format(archive2)
     if format1 == format2 and compression1 == compression2:
         # same format and compression allows to copy the file
-        util.link_or_copy(archive1, archive2, verbosity=verbosity)
+        fileutil.link_or_copy(archive1, archive2, verbosity=verbosity)
         return
-    tmpdir = util.tmpdir()
+    tmpdir = fileutil.tmpdir()
     try:
         kwargs = dict(verbosity=verbosity, outdir=tmpdir, password=password)
         same_format = (format1 == format2 and compression1 and compression2)
@@ -756,100 +726,62 @@ def _repack_archive (archive1, archive2, verbosity=0, interactive=True, password
         finally:
             os.chdir(olddir)
     finally:
-        shutil.rmtree(tmpdir, onerror=rmtree_log_error)
-
-
-def _recompress_archive(archive, verbosity=0, interactive=True, password=None):
-    """Try to recompress an archive to smaller size."""
-    format, compression = get_archive_format(archive)
-    if compression:
-        # only recompress the compression itself (e.g. for .tar.xz)
-        format = compression
-    tmpdir = util.tmpdir()
-    tmpdir2 = util.tmpdir()
-    base, ext = os.path.splitext(os.path.basename(archive))
-    archive2 = util.get_single_outfile(tmpdir2, base, extension=ext)
-    try:
-        # extract
-        kwargs = dict(verbosity=verbosity, format=format, outdir=tmpdir, password=password)
-        path = _extract_archive(archive, **kwargs)
-        # compress to new file
-        olddir = os.getcwd()
-        os.chdir(path)
-        try:
-            kwargs = dict(verbosity=verbosity, interactive=interactive, format=format, password=password)
-            files = tuple(os.listdir(path))
-            _create_archive(archive2, files, **kwargs)
-        finally:
-            os.chdir(olddir)
-        # check file sizes and replace if new file is smaller
-        filesize = util.get_filesize(archive)
-        filesize2 = util.get_filesize(archive2)
-        if filesize2 < filesize:
-            # replace file
-            os.remove(archive)
-            shutil.move(archive2, archive)
-            diffsize = filesize - filesize2
-            return "... recompressed file is now %s smaller." % util.strsize(diffsize)
-    finally:
-        shutil.rmtree(tmpdir, onerror=rmtree_log_error)
-        shutil.rmtree(tmpdir2, onerror=rmtree_log_error)
-    return "... recompressed file is not smaller, leaving archive as is."
+        fileutil.rmtree(tmpdir)
 
 
 # the patool library API
 
 def extract_archive(archive, verbosity=0, outdir=None, program=None, interactive=True, password=None):
     """Extract given archive."""
-    util.check_existing_filename(archive)
+    fileutil.check_existing_filename(archive)
     if verbosity >= 0:
-        util.log_info("Extracting %s ..." % archive)
+        log.log_info(f"Extracting {archive} ...")
     return _extract_archive(archive, verbosity=verbosity, interactive=interactive, outdir=outdir, program=program, password=password)
 
 
 def list_archive(archive, verbosity=1, program=None, interactive=True, password=None):
     """List given archive."""
     # Set default verbosity to 1 since the listing output should be visible.
-    util.check_existing_filename(archive)
+    fileutil.check_existing_filename(archive)
     if verbosity >= 0:
-        util.log_info("Listing %s ..." % archive)
+        log.log_info(f"Listing {archive} ...")
     return _handle_archive(archive, 'list', verbosity=verbosity, interactive=interactive, program=program, password=password)
 
 
 def test_archive(archive, verbosity=0, program=None, interactive=True, password=None):
     """Test given archive."""
-    util.check_existing_filename(archive)
+    fileutil.check_existing_filename(archive)
     if verbosity >= 0:
-        util.log_info("Testing %s ..." % archive)
+        log.log_info(f"Testing {archive} ...")
     res = _handle_archive(archive, 'test', verbosity=verbosity,
         interactive=interactive, program=program, password=password)
     if verbosity >= 0:
-        util.log_info("... tested ok.")
+        log.log_info("... tested ok.")
     return res
 
 
 def create_archive(archive, filenames, verbosity=0, program=None, interactive=True, password=None):
     """Create given archive with given files."""
-    util.check_new_filename(archive)
-    util.check_archive_filelist(filenames)
+    fileutil.check_new_filename(archive)
+    fileutil.check_archive_filelist(filenames)
     if verbosity >= 0:
-        util.log_info("Creating %s ..." % archive)
+        log.log_info(f"Creating {archive} ...")
     res = _create_archive(archive, filenames, verbosity=verbosity,
                           interactive=interactive, program=program, password=password)
     if verbosity >= 0:
-        util.log_info("... %s created." % archive)
+        log.log_info(f"... {archive} created.")
     return res
 
 
 def diff_archives(archive1, archive2, verbosity=0, interactive=True):
     """Print differences between two archives."""
-    util.check_existing_filename(archive1)
-    util.check_existing_filename(archive2)
+    fileutil.check_existing_filename(archive1)
+    fileutil.check_existing_filename(archive2)
     if verbosity >= 0:
-        util.log_info("Comparing %s with %s ..." % (archive1, archive2))
+        log.log_info(f"Comparing {archive1} with {archive2} ...")
     res = _diff_archives(archive1, archive2, verbosity=verbosity, interactive=interactive)
     if res == 0 and verbosity >= 0:
-        util.log_info("... no differences found.")
+        log.log_info("... no differences found.")
     return res
 
 
@@ -857,34 +789,22 @@ def search_archive(pattern, archive, verbosity=0, interactive=True, password=Non
     """Search pattern in archive members."""
     if not pattern:
         raise util.PatoolError("empty search pattern")
-    util.check_existing_filename(archive)
+    fileutil.check_existing_filename(archive)
     if verbosity >= 0:
-        util.log_info("Searching %r in %s ..." % (pattern, archive))
+        log.log_info(f"Searching {pattern!r} in {archive} ...")
     res = _search_archive(pattern, archive, verbosity=verbosity, interactive=interactive, password=password)
     if res == 1 and verbosity >= 0:
-        util.log_info("... %r not found" % pattern)
+        log.log_info(f"... {pattern!r} not found")
     return res
 
 
-def repack_archive (archive, archive_new, verbosity=0, interactive=True, password=None):
+def repack_archive(archive, archive_new, verbosity=0, interactive=True, password=None):
     """Repack archive to different file and/or format."""
-    util.check_existing_filename(archive)
-    util.check_new_filename(archive_new)
+    fileutil.check_existing_filename(archive)
+    fileutil.check_new_filename(archive_new)
     if verbosity >= 0:
-        util.log_info("Repacking %s to %s ..." % (archive, archive_new))
+        log.log_info(f"Repacking {archive} to {archive_new} ...")
     res = _repack_archive(archive, archive_new, verbosity=verbosity, interactive=interactive, password=password)
     if verbosity >= 0:
-        util.log_info("... repacking successful.")
+        log.log_info("... repacking successful.")
     return res
-
-
-def recompress_archive(archive, verbosity=0, interactive=True, password=None):
-    """Recompress an archive to hopefully smaller size."""
-    util.check_existing_filename(archive)
-    util.check_writable_filename(archive)
-    if verbosity >= 0:
-        util.log_info("Recompressing %s ..." % (archive,))
-    res = _recompress_archive(archive, verbosity=verbosity, interactive=interactive, password=password)
-    if res and verbosity >= 0:
-        util.log_info(res)
-    return 0
