@@ -22,10 +22,10 @@ def extract_7z(archive, compression, cmd, verbosity, interactive, outdir, passwo
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
+        cmdlist.append(f'-p{password}')
     elif not interactive:
         cmdlist.append('-p-')
-    cmdlist.extend(['-o%s' % outdir, '--', archive])
+    cmdlist.extend([f'-o{outdir}', '--', archive])
     return cmdlist
 
 def extract_7z_singlefile(archive, compression, cmd, verbosity, interactive, outdir, password=None):
@@ -36,10 +36,10 @@ def extract_7z_singlefile(archive, compression, cmd, verbosity, interactive, out
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
+        cmdlist.append(f'-p{password}')
     elif not interactive:
         cmdlist.append('-p-')
-    cmdlist.extend(['-o%s' % outdir, '--', archive])
+    cmdlist.extend([f'-o{outdir}', '--', archive])
     return cmdlist
 
 extract_bzip2 = \
@@ -61,13 +61,13 @@ extract_zip = \
   extract_vhd = \
   extract_7z
 
-def list_7z (archive, compression, cmd, verbosity, interactive, password=None):
+def list_7z(archive, compression, cmd, verbosity, interactive, password=None):
     """List a 7z archive."""
     cmdlist = [cmd, 'l']
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
+        cmdlist.append(f'-p{password}')
     elif not interactive:
         cmdlist.append('-p-')
     cmdlist.extend(['--', archive])
@@ -91,13 +91,13 @@ list_bzip2 = \
   list_7z
 
 
-def test_7z (archive, compression, cmd, verbosity, interactive, password=None):
+def test_7z(archive, compression, cmd, verbosity, interactive, password=None):
     """Test a 7z archive."""
     cmdlist = [cmd, 't']
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
+        cmdlist.append(f'-p{password}')
     elif not interactive:
         cmdlist.append('-p-')
     cmdlist.extend(['--', archive])
@@ -127,10 +127,10 @@ def create_7z(archive, compression, cmd, verbosity, interactive, filenames, pass
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
+        cmdlist.append(f'-p{password}')
         # encrypt the file list, ie. "patool list" will require a password
         cmdlist.append('-mhe=on')
-    cmdlist.extend(['-t7z', '-mx=9', '--', archive])
+    cmdlist.extend(['-t7z', '-sae', '--', archive])
     cmdlist.extend(filenames)
     return cmdlist
 
@@ -141,8 +141,8 @@ def create_zip(archive, compression, cmd, verbosity, interactive, filenames, pas
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
-    cmdlist.extend(['-tzip', '-mx=9', '--', archive])
+        cmdlist.append(f'-p{password}')
+    cmdlist.extend(['-tzip', '--', archive])
     cmdlist.extend(filenames)
     return cmdlist
 
@@ -153,8 +153,8 @@ def create_xz(archive, compression, cmd, verbosity, interactive, filenames, pass
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
-    cmdlist.extend(['-txz', '-mx=9', '--', archive])
+        cmdlist.append(f'-p{password}')
+    cmdlist.extend(['-txz', '--', archive])
     cmdlist.extend(filenames)
     return cmdlist
 
@@ -165,8 +165,8 @@ def create_gzip(archive, compression, cmd, verbosity, interactive, filenames, pa
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
-    cmdlist.extend(['-tgzip', '-mx=9', '--', archive])
+        cmdlist.append(f'-p{password}')
+    cmdlist.extend(['-tgzip', '--', archive])
     cmdlist.extend(filenames)
     return cmdlist
 
@@ -177,7 +177,7 @@ def create_bzip2(archive, compression, cmd, verbosity, interactive, filenames, p
     if not interactive:
         cmdlist.append('-y')
     if password:
-        cmdlist.append('-p%s' % password)
-    cmdlist.extend(['-tbzip2', '-mx=9', '--', archive])
+        cmdlist.append(f'-p{password}')
+    cmdlist.extend(['-tbzip2', '--', archive])
     cmdlist.extend(filenames)
     return cmdlist
