@@ -14,15 +14,15 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the bz2 Python module."""
-from .. import util
+from .. import fileutil, util
 import bz2
 
 # read in 1MB chunks
 READ_SIZE_BYTES = 1024*1024
 
-def extract_bzip2 (archive, compression, cmd, verbosity, interactive, outdir):
+def extract_bzip2(archive, compression, cmd, verbosity, interactive, outdir):
     """Extract a BZIP2 archive with the bz2 Python module."""
-    targetname = util.get_single_outfile(outdir, archive)
+    targetname = fileutil.get_single_outfile(outdir, archive)
     try:
         with bz2.BZ2File(archive) as bz2file:
             with open(targetname, 'wb') as targetfile:
@@ -31,12 +31,12 @@ def extract_bzip2 (archive, compression, cmd, verbosity, interactive, outdir):
                     targetfile.write(data)
                     data = bz2file.read(READ_SIZE_BYTES)
     except Exception as err:
-        msg = "error extracting %s to %s" % (archive, targetname)
+        msg = f"error extracting {archive} to {targetname}"
         raise util.PatoolError(msg) from err
     return None
 
 
-def create_bzip2 (archive, compression, cmd, verbosity, interactive, filenames):
+def create_bzip2(archive, compression, cmd, verbosity, interactive, filenames):
     """Create a BZIP2 archive with the bz2 Python module."""
     if len(filenames) > 1:
         raise util.PatoolError('multi-file compression not supported in Python bz2')
@@ -49,6 +49,6 @@ def create_bzip2 (archive, compression, cmd, verbosity, interactive, filenames):
                     bz2file.write(data)
                     data = srcfile.read(READ_SIZE_BYTES)
     except Exception as err:
-        msg = "error creating %s" % (archive, )
+        msg = f"error creating {archive}"
         raise util.PatoolError(msg) from err
     return None
