@@ -15,39 +15,34 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the lzma Python module."""
 
-from .. import util
+from .. import fileutil, util
 import lzma
 
 READ_SIZE_BYTES = 1024*1024
 
 # Adapters for different lzma bindings.
 if hasattr(lzma, 'FORMAT_ALONE'):
-    def _get_lzma_options(format, preset=None):
-        kwargs = {'format':
-                    {'alone': lzma.FORMAT_ALONE,
-                     'xz': lzma.FORMAT_XZ,
-                     }[format]
-                }
-        if preset:
-            kwargs['preset'] = preset
-        return kwargs
+    def _get_lzma_options(format):
+        return {
+            'format': {
+                'alone': lzma.FORMAT_ALONE,
+                'xz': lzma.FORMAT_XZ,
+                }[format]
+            }
 else:
     # might not be available e.g. in Debian's python-lzma 0.5.3
     # which is pyliblzma.
-    def _get_lzma_options(format, preset=None):
-        kwargs = {
+    def _get_lzma_options(format):
+        return {
             'options': {
                 'format': format
             }
         }
-        if preset:
-            kwargs['options']['level'] = preset
-        return kwargs
 
 
 def _extract(archive, compression, cmd, format, verbosity, outdir):
     """Extract an LZMA or XZ archive with the lzma Python module."""
-    targetname = util.get_single_outfile(outdir, archive)
+    targetname = fileutil.get_single_outfile(outdir, archive)
     try:
         with lzma.LZMAFile(archive, **_get_lzma_options(format)) as lzmafile:
             with open(targetname, 'wb') as targetfile:
@@ -56,7 +51,7 @@ def _extract(archive, compression, cmd, format, verbosity, outdir):
                     targetfile.write(data)
                     data = lzmafile.read(READ_SIZE_BYTES)
     except Exception as err:
-        msg = "error extracting %s to %s" % (archive, targetname)
+        msg = f"error extracting {archive} to {targetname}"
         raise util.PatoolError(msg) from err
     return None
 
@@ -74,7 +69,7 @@ def _create(archive, compression, cmd, format, verbosity, filenames):
     if len(filenames) > 1:
         raise util.PatoolError('multi-file compression not supported in Python lzma')
     try:
-        with lzma.LZMAFile(archive, mode='wb', **_get_lzma_options(format, preset=9)) as lzmafile:
+        with lzma.LZMAFile(archive, mode='wb', **_get_lzma_options(format)) as lzmafile:
             filename = filenames[0]
             with open(filename, 'rb') as srcfile:
                 data = srcfile.read(READ_SIZE_BYTES)
@@ -82,8 +77,7 @@ def _create(archive, compression, cmd, format, verbosity, filenames):
                     lzmafile.write(data)
                     data = srcfile.read(READ_SIZE_BYTES)
     except Exception as err:
-        msg = "error creating %s" % (archive, )
-        raise util.PatoolError(msg) from err
+        raise util.PatoolError(f"error creating {archive}") from err
     return None
 
 def create_lzma(archive, compression, cmd, verbosity, interactive, filenames):
