@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the GNU tar program."""
 import os
-import sys
+import subprocess
 
 
 def extract_tar (archive, compression, cmd, verbosity, interactive, outdir):
@@ -42,7 +42,7 @@ def create_tar (archive, compression, cmd, verbosity, interactive, filenames):
     cmdlist.extend(filenames)
     return cmdlist
 
-def add_tar_opts (cmdlist, compression, verbosity):
+def add_tar_opts(cmdlist, compression, verbosity):
     """Add tar options to cmdlist."""
     progname = os.path.basename(cmdlist[0]).lower()
     if progname.endswith('.exe'):
@@ -53,24 +53,16 @@ def add_tar_opts (cmdlist, compression, verbosity):
         cmdlist.append('-Z')
     elif compression == 'bzip2':
         cmdlist.append('-j')
-    elif compression in ('lzma', 'xz') and progname == 'bsdtar':
-        cmdlist.append('--%s' % compression)
-    elif compression in ('lzma', 'xz', 'lzip'):
-        # use the compression name as program name since
-        # tar is picky which programs it can use
-        program = compression
-        # set compression program
-        cmdlist.extend(['--use-compress-program', program])
+    elif compression == 'xz':
+        cmdlist.append('-J')
+    elif compression in ('lzma', 'lzip'):
+        cmdlist.append(f'--{compression}')
     if verbosity > 1:
         cmdlist.append('--verbose')
     if progname == 'tar':
-        if sys.platform == 'darwin':
-            # On MacOS, the default tar does not support --force-local
-            # but "brew install gnu-tar" could have been used, so test for it
-            testcmdlist = [cmdlist[0], "--force-local", "--help"]
-            from .. import util
-            if util.run(testcmdlist) == 0:
-                cmdlist.append('--force-local')
-        else:
-            # assume "tar" is GNU tar and therefore supports --force-local
+        # Some tar implementations (ie. Windows tar.exe, and macos)
+        # do not support --force-local
+        testcmdlist = [cmdlist[0], "--force-local", "--help"]
+        from .. import util
+        if util.run(testcmdlist, stderr=subprocess.DEVNULL) == 0:
             cmdlist.append('--force-local')
