@@ -15,13 +15,24 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the unalz program."""
 
-def extract_alzip (archive, compression, cmd, verbosity, interactive, outdir):
+def _maybe_add_password(cmdlist, password):
+    if password:
+        cmdlist.extend(['-pwd', password])
+
+
+def extract_alzip (archive, compression, cmd, verbosity, interactive, outdir, password=None):
     """Extract a ALZIP archive."""
-    return [cmd, '-d', outdir, archive]
+    cmdlist = [cmd, '-d', outdir]
+    _maybe_add_password(cmdlist, password)
+    cmdlist.append(archive)
+    return cmdlist
 
 
-def list_alzip (archive, compression, cmd, verbosity, interactive):
+def list_alzip (archive, compression, cmd, verbosity, interactive, password=None):
     """List a ALZIP archive."""
-    return [cmd, '-l', archive]
+    cmdlist = [cmd, '-l']
+    _maybe_add_password(cmdlist, password)
+    cmdlist.append(archive)
+    return cmdlist
 
 test_alzip = list_alzip
