@@ -14,7 +14,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the uncompress.real program."""
-from .. import util
+from .. import util, fileutil
 
 
 def extract_compress (archive, compression, cmd, verbosity, interactive, outdir):
@@ -22,7 +22,7 @@ def extract_compress (archive, compression, cmd, verbosity, interactive, outdir)
     cmdlist = [util.shell_quote(cmd)]
     if verbosity > 1:
         cmdlist.append('-v')
-    outfile = util.get_single_outfile(outdir, archive)
+    outfile = fileutil.get_single_outfile(outdir, archive)
     cmdlist.extend(['-c', util.shell_quote(archive), '>',
                     util.shell_quote(outfile)])
     return (cmdlist, {'shell': True})
