@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,7 +15,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import unittest
 import os
-import shutil
 import patoolib
 from .. import basedir, datadir
 
@@ -64,20 +63,20 @@ class ArchiveTest (unittest.TestCase):
         if not kwargs.get('skip_create'):
             self.archive_create(filename, **kwargs)
 
-    def archive_extract (self, filename, check=Content.Recursive):
+    def archive_extract(self, filename, check=Content.Recursive):
         """Test archive extraction."""
         archive = os.path.join(datadir, filename)
-        self.assertTrue(os.path.isabs(archive), "archive path is not absolute: %r" % archive)
+        self.assertTrue(os.path.isabs(archive), f"archive path is not absolute: {archive!r}")
         self._archive_extract(archive, check)
         # archive name relative to tmpdir
         relarchive = os.path.join("..", archive[len(basedir)+1:])
         self._archive_extract(relarchive, check, verbosity=1)
 
-    def _archive_extract (self, archive, check, verbosity=0):
+    def _archive_extract(self, archive, check, verbosity=0):
         # create a temporary directory for extraction
-        tmpdir = patoolib.util.tmpdir(dir=basedir)
+        tmpdir = patoolib.fileutil.tmpdir(dir=basedir, prefix="test_")
         try:
-            olddir = patoolib.util.chdir(tmpdir)
+            olddir = patoolib.fileutil.chdir(tmpdir)
             try:
                 output = patoolib.extract_archive(archive, program=self.program, verbosity=verbosity, interactive=False, password=self.password)
                 if check:
@@ -86,9 +85,9 @@ class ArchiveTest (unittest.TestCase):
                 if olddir:
                     os.chdir(olddir)
         finally:
-            shutil.rmtree(tmpdir)
+            patoolib.fileutil.rmtree(tmpdir)
 
-    def check_extracted_archive (self, archive, output, check):
+    def check_extracted_archive(self, archive, output, check):
         if check == Content.Recursive:
             # outdir is the 't' directory of the archive
             self.assertEqual(output, 't')
@@ -97,8 +96,7 @@ class ArchiveTest (unittest.TestCase):
             self.check_textfile(txtfile, 't.txt')
         elif check == Content.Singlefile:
             # a non-existing directory to ensure files do not exist in it
-            ned = get_nonexisting_directory(os.getcwd())
-            expected_output = os.path.basename(patoolib.util.get_single_outfile(ned, archive))
+            expected_output = self.get_expected_singlefile_output(archive)
             self.check_textfile(output, expected_output)
         elif check == Content.Multifile:
             txtfile = os.path.join(output, 't.txt')
@@ -106,6 +104,12 @@ class ArchiveTest (unittest.TestCase):
             txtfile2 = os.path.join(output, 't2.txt')
             self.check_textfile(txtfile2, 't2.txt')
 
+    def get_expected_singlefile_output(self, archive):
+        """Return the expected output file name of a singlefile archive."""
+        if archive.endswith(".foo"):
+            return patoolib.fileutil.stripext(os.path.basename(archive))
+        return "t.txt"
+
     def check_directory (self, dirname, expectedname):
         """Check that directory exists."""
         self.assertTrue(os.path.isdir(dirname), dirname)
@@ -129,7 +133,7 @@ class ArchiveTest (unittest.TestCase):
         for verbosity in (-1, 0, 1, 2):
             patoolib.test_archive(archive, program=self.program, verbosity=verbosity, interactive=False, password=self.password)
 
-    def archive_create (self, archive, srcfiles=None, check=Content.Recursive):
+    def archive_create(self, archive, srcfiles=None, check=Content.Recursive):
         """Test archive creation."""
         if srcfiles is None:
             if check == Content.Recursive:
@@ -139,8 +143,8 @@ class ArchiveTest (unittest.TestCase):
             elif check == Content.Multifile:
                 srcfiles = ('t.txt', 't2.txt',)
             else:
-                raise ValueError('invalid check value %r' % check)
-        olddir = patoolib.util.chdir(datadir)
+                raise ValueError('invalid check value {check!r}')
+        olddir = patoolib.fileutil.chdir(datadir)
         try:
             # The format and compression arguments are needed for creating
             # archives with unusual file extensions.
@@ -156,16 +160,16 @@ class ArchiveTest (unittest.TestCase):
             self.assertFalse(os.path.isabs(srcfile))
             self.assertTrue(os.path.exists(srcfile))
         # create a temporary directory for creation
-        tmpdir = patoolib.util.tmpdir(dir=basedir)
+        tmpdir = patoolib.fileutil.tmpdir(dir=basedir)
         try:
             archive = os.path.join(tmpdir, archive)
-            self.assertTrue(os.path.isabs(archive), "archive path is not absolute: %r" % archive)
+            self.assertTrue(os.path.isabs(archive), f"archive path is not absolute: {archive!r}")
             patoolib.create_archive(archive, srcfiles, verbosity=verbosity, interactive=False, program=program, password=self.password)
             self.assertTrue(os.path.isfile(archive))
             self.check_created_archive_with_test(archive)
             self.check_created_archive_with_diff(archive, srcfiles)
         finally:
-            shutil.rmtree(tmpdir)
+            patoolib.fileutil.rmtree(tmpdir)
 
     def check_created_archive_with_test(self, archive):
         command = patoolib.test_archive
@@ -208,9 +212,9 @@ class ArchiveTest (unittest.TestCase):
             program = 'unshar'
         elif self.program == 'genisoimage':
             program = '7z'
-        tmpdir = patoolib.util.tmpdir(dir=basedir)
+        tmpdir = patoolib.fileutil.tmpdir(dir=basedir)
         try:
-            olddir = patoolib.util.chdir(tmpdir)
+            olddir = patoolib.fileutil.chdir(tmpdir)
             try:
                 output = patoolib.extract_archive(archive, program=program, interactive=False, password=self.password)
                 if len(srcfiles) == 1:
@@ -225,7 +229,7 @@ class ArchiveTest (unittest.TestCase):
                 if olddir:
                     os.chdir(olddir)
         finally:
-            shutil.rmtree(tmpdir)
+            patoolib.fileutil.rmtree(tmpdir)
 
 
 def get_filecontent(filename):
@@ -236,10 +240,4 @@ def get_filecontent(filename):
 
 def get_nonexisting_directory(basedir):
     """Note: this is _not_ intended to be used to create a directory."""
-    d = os.path.join(basedir, "foo")
-    while os.path.exists(d):
-        d += 'a'
-        if len(d) > 100:
-            # wtf
-            raise ValueError('could not construct unique directory name at %r' % basedir)
-    return d
+    return patoolib.fileutil.get_single_outfile(basedir, "foo")
