@@ -16,12 +16,12 @@
 from . import ArchiveTest, Content
 from .. import needs_program, needs_codec
 
-class Test7z (ArchiveTest):
+class Test7z(ArchiveTest):
 
     program = '7z'
 
     @needs_program(program)
-    def test_7z (self):
+    def test_7z(self):
         self.archive_commands('t .7z')
         self.archive_commands('t .cb7')
         self.archive_commands('t.zip')
@@ -33,6 +33,7 @@ class Test7z (ArchiveTest):
         self.archive_list('t.jar')
         self.archive_list('t.txt.Z')
         self.archive_list('t.cab')
+        self.archive_list('t.chm')
         self.archive_list('t.arj')
         self.archive_list('t.cpio')
         self.archive_list('t.rpm')
@@ -45,6 +46,7 @@ class Test7z (ArchiveTest):
         self.archive_extract('t.jar', check=None)
         self.archive_extract('t.txt.Z', check=Content.Singlefile)
         self.archive_extract('t.cab')
+        self.archive_extract('t.chm', check=None)
         self.archive_extract('t.arj')
         self.archive_extract('t.cpio')
         self.archive_extract('t.rpm', check=None)
@@ -57,6 +59,7 @@ class Test7z (ArchiveTest):
         self.archive_test('t.jar')
         self.archive_test('t.txt.Z')
         self.archive_test('t.cab')
+        self.archive_test('t.chm')
         self.archive_test('t.arj')
         self.archive_test('t.cpio')
         self.archive_test('t.rpm')
@@ -67,7 +70,7 @@ class Test7z (ArchiveTest):
         self.archive_create('t.txt.bz2', check=Content.Singlefile)
 
     @needs_codec(program, 'rar')
-    def test_7z_rar (self):
+    def test_7z_rar(self):
         # only succeeds with the rar module for 7z installed
         self.archive_list('t.rar')
         self.archive_extract('t.rar')
@@ -75,7 +78,7 @@ class Test7z (ArchiveTest):
 
     @needs_program('file')
     @needs_program(program)
-    def test_7z_file (self):
+    def test_7z_file(self):
         self.archive_commands('t.7z.foo', skip_create=True)
         self.archive_commands('t.cb7.foo', skip_create=True)
         self.archive_commands('t.zip.foo', skip_create=True)
@@ -86,6 +89,7 @@ class Test7z (ArchiveTest):
         self.archive_list('t.jar.foo')
         self.archive_list('t.txt.Z.foo')
         self.archive_list('t.cab.foo')
+        self.archive_list('t.chm.foo')
         self.archive_list('t.arj.foo')
         self.archive_list('t.cpio.foo')
         self.archive_list('t.rpm.foo')
@@ -96,6 +100,7 @@ class Test7z (ArchiveTest):
         self.archive_extract('t.jar.foo', check=None)
         self.archive_extract('t.txt.Z.foo', check=Content.Singlefile)
         self.archive_extract('t.cab.foo')
+        self.archive_extract('t.chm.foo', check=None)
         self.archive_extract('t.arj.foo')
         self.archive_extract('t.cpio.foo')
         self.archive_extract('t.rpm.foo', check=None)
@@ -106,6 +111,7 @@ class Test7z (ArchiveTest):
         self.archive_test('t.jar.foo')
         self.archive_test('t.txt.Z.foo')
         self.archive_test('t.cab.foo')
+        self.archive_test('t.chm.foo')
         self.archive_test('t.arj.foo')
         self.archive_test('t.cpio.foo')
         self.archive_test('t.rpm.foo')
@@ -114,8 +120,42 @@ class Test7z (ArchiveTest):
 
     @needs_program('file')
     @needs_codec(program, 'rar')
-    def test_7z_rar_file (self):
+    def test_7z_rar_file(self):
         # only succeeds with the rar module for 7z installed
-        self.archive_list('t.rar.foo')
-        self.archive_extract('t.rar.foo')
-        self.archive_test('t.rar.foo')
+        self.archive_list(self.filename + '.rar.foo')
+        self.archive_extract(self.filename + '.rar.foo')
+        self.archive_test(self.filename + '.rar.foo')
+
+
+class Test7zPassword(ArchiveTest):
+
+    program = '7z'
+    password = 'thereisnotry'
+
+    @needs_program(program)
+    def test_7z(self):
+        self.archive_commands('p .7z')
+        self.archive_commands('p.zip')
+        self.archive_commands('p.cbz')
+
+    @needs_codec(program, 'rar')
+    def test_7z_rar(self):
+        # only succeeds with the rar module for 7z installed
+        self.archive_list('p.rar')
+        self.archive_extract('p.rar')
+        self.archive_test('p.rar')
+
+    @needs_program('file')
+    @needs_program(program)
+    def test_7z_file(self):
+        self.archive_commands('p.7z.foo', skip_create=True)
+        self.archive_commands('p.zip.foo', skip_create=True)
+        self.archive_commands('p.cbz.foo', skip_create=True)
+
+    @needs_program('file')
+    @needs_codec(program, 'rar')
+    def test_7z_rar_file(self):
+        # only succeeds with the rar module for 7z installed
+        self.archive_list('p.rar.foo')
+        self.archive_extract('p.rar.foo')
+        self.archive_test('p.rar.foo')
