@@ -22,12 +22,27 @@ class TestRar (ArchiveTest):
 
     @needs_program(program)
     def test_rar(self):
-        self.archive_commands('t.rar')
-        self.archive_commands('t.cbr')
+        self.archive_commands(self.filename + '.rar')
+        self.archive_commands(self.filename + '.cbr')
 
     @needs_program('file')
     @needs_program(program)
     def test_rar_file(self):
-        self.archive_commands('t.rar.foo', skip_create=True)
-        self.archive_commands('t.cbr.foo', skip_create=True)
+        self.archive_commands(self.filename + '.rar.foo', skip_create=True)
+        self.archive_commands(self.filename + '.cbr.foo', skip_create=True)
 
+
+class TestRarPassword (ArchiveTest):
+
+    filename = 'p'
+    password = 'thereisnotry'
+    program = 'rar'
+
+    @needs_program(program)
+    def test_rar(self):
+        self.archive_commands(self.filename + '.rar')
+
+    @needs_program('file')
+    @needs_program(program)
+    def test_rar_file(self):
+        self.archive_commands(self.filename + '.rar.foo', skip_create=True)
