@@ -16,16 +16,16 @@
 from . import ArchiveTest
 from .. import needs_program
 
-class TestUnzip (ArchiveTest):
+class TestUnzip(ArchiveTest):
 
     program = 'unzip'
 
     @needs_program(program)
-    def test_unzip (self):
-        self.archive_extract('t.zip', check=None)
+    def test_unzip(self):
+        self.archive_extract('t.zip')
         self.archive_list('t.zip')
         self.archive_test('t.zip')
-        self.archive_extract('t.cbz', check=None)
+        self.archive_extract('t.cbz')
         self.archive_list('t.cbz')
         self.archive_test('t.cbz')
         self.archive_extract('t.jar', check=None)
@@ -40,11 +40,11 @@ class TestUnzip (ArchiveTest):
 
     @needs_program('file')
     @needs_program(program)
-    def test_unzip_file (self):
-        self.archive_extract('t.zip.foo', check=None)
+    def test_unzip_file(self):
+        self.archive_extract('t.zip.foo')
         self.archive_list('t.zip.foo')
         self.archive_test('t.zip.foo')
-        self.archive_extract('t.cbz.foo', check=None)
+        self.archive_extract('t.cbz.foo')
         self.archive_list('t.cbz.foo')
         self.archive_test('t.cbz.foo')
         self.archive_extract('t.jar.foo', check=None)
@@ -58,26 +58,26 @@ class TestUnzip (ArchiveTest):
         self.archive_test('t.apk.foo')
 
 
-class TestUnzipPassword (ArchiveTest):
+class TestUnzipPassword(ArchiveTest):
 
     program = 'unzip'
     password = 'thereisnotry'
 
     @needs_program(program)
-    def test_unzip (self):
-        self.archive_extract('p.zip', check=None)
+    def test_unzip(self):
+        self.archive_extract('p.zip')
         self.archive_list('p.zip')
         self.archive_test('p.zip')
-        self.archive_extract('p.cbz', check=None)
+        self.archive_extract('p.cbz')
         self.archive_list('p.cbz')
         self.archive_test('p.cbz')
 
     @needs_program('file')
     @needs_program(program)
-    def test_unzip_file (self):
-        self.archive_extract('p.zip.foo', check=None)
+    def test_unzip_file(self):
+        self.archive_extract('p.zip.foo')
         self.archive_list('p.zip.foo')
         self.archive_test('p.zip.foo')
-        self.archive_extract('p.cbz.foo', check=None)
+        self.archive_extract('p.cbz.foo')
         self.archive_list('p.cbz.foo')
         self.archive_test('p.cbz.foo')
