@@ -14,20 +14,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 from . import ArchiveTest, Content
-from .. import needs_program, skip_on_travis
+from .. import needs_program
 
 class TestZoo (ArchiveTest):
 
     program = 'zoo'
 
-    # On a Travis CI build the test fails.
-    @skip_on_travis()
     @needs_program(program)
     def test_zoo(self):
         self.archive_commands('t.zoo', check=Content.Multifile)
 
-    # On a Travis CI build the test fails.
-    @skip_on_travis()
     @needs_program('file')
     @needs_program(program)
     def test_zoo_file(self):
