@@ -40,10 +40,10 @@ class TestConfiguration (unittest.TestCase):
 
     def test_encoding_mimes (self):
         self.assertEqual(set(patoolib.ArchiveCompressions),
-                         set(patoolib.util.Encoding2Mime.keys()))
-        for mime in patoolib.util.Encoding2Mime.values():
+                         set(patoolib.mime.Encoding2Mime.keys()))
+        for mime in patoolib.mime.Encoding2Mime.values():
             self.assertTrue(mime in patoolib.ArchiveMimetypes)
 
     def test_filetext_mime (self):
-        for mime in patoolib.util.FileText2Mime.values():
+        for mime in patoolib.mime.FileText2Mime.values():
             self.assertTrue(mime in patoolib.ArchiveMimetypes)
