@@ -15,8 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 import unittest
 import os
-import shutil
-from patoolib import util, cli
+from patoolib import fileutil, cli
 from . import basedir, datadir, needs_program
 
 
@@ -24,10 +23,10 @@ class ArchiveExtractTest(unittest.TestCase):
 
     @needs_program('7z')
     def test_extract(self):
-        tmpdir = util.tmpdir(dir=basedir)
+        tmpdir = fileutil.tmpdir(dir=basedir)
         try:
             archive = os.path.join(datadir, "t .7z")
             args = ["-vv", "--non-interactive", "extract", "--outdir", tmpdir, archive]
             cli.main(args=args)
         finally:
-            shutil.rmtree(tmpdir)
+            fileutil.rmtree(tmpdir)
